@@ -1,10 +1,10 @@
-__all__=['read_lasio','read_lasios','plots','visualizations','evaluate_reservoir']
+__all__=['read_lasio','read_lasios','plots','visualizations','evaluate_reservoir', 'preprocessing']
 
-from petroeval import visualizations
+from petroeval import visualizations, preprocessing
 from petroeval import evaluate_reservoir, plots
 from .evaluate_reservoir import FormationEvaluation
 from .visualizations import log_plot
 from petroeval import files_reader
 from petroeval.files_reader import  read_lasio,read_lasios
 
-from .plots import *
+from .plots import *
\ No newline at end of file
