@@ -5,6 +5,8 @@ Author: Ibrahim Olawale
 
 import numpy as np
 import pandas as pd
+import warnings
+warnings.filterwarnings("ignore")
 
 
 class FormationEvaluation:
@@ -73,13 +75,6 @@ class FormationEvaluation:
             elif use_mean == False:
                 cols = list(data.columns)
                 data = data.fillna(value)
-                #'''
-                #    for i in range(len(data[col])):
-                #        if np.isnan(data[col].iloc[i]):
-                #            
-                #            data[col].iloc[i] = value
-                #        else:
-                #            data[col].iloc[i] = data[col].iloc[i]
                
 
             return data
@@ -130,79 +125,45 @@ class FormationEvaluation:
         try:
             #converting resistivity values of 0 to 0.01
             
-            data[self.RT] = np.where(data[self.RT]==0, 0.01, data[self.RT])
-            for i in range(data.shape[0]):
-                if data[self.RT].iloc[i] == 0:
-                    data[self.RT].iloc[i] = 0.1
-                else:
-                    data[self.RT].iloc[i] == data[self.RT].iloc[i]
+            #data[self.RT] = np.where(data[self.RT]==0, 0.01, data[self.RT])
+            data.loc[data[self.RT] == 0, 'RT'] = 0.01
         
         
-            #to classify each point as shale or sandstone based on the Gamma Ray readings
-            df3['litho'] = 0
+            #to classify each point as shale or sandstone based on the Gamma Ray readings (flags)
+            #df3['litho'] = 0
             
-            for i in range(data.shape[0]):
-                
-                if (data[GR].iloc[i] < cutoff_test):
-                    df3['litho'].iloc[i] = 1
-                else:
-                    df3['litho'].iloc[i] = 0
-
-            vsh = []
+            df3.loc[df3.GR < cutoff_test, 'litho'] = 0
+            df3.loc[df3.GR > cutoff_test, 'litho'] = 1
 
             min_GR = data[GR].min()
             max_GR = data[GR].max()
 
-            for i in range(data.shape[0]):
+            #data['IGR'] = 0
+            data['IGR'] = (data[GR] - min_GR) / (max_GR - min_GR)
+            #data['reading'] = 0
+            data['reading'] = (0.083 * (2 ** (3.7 * data['IGR']) - 1))
+            #df3['vsh'] = 0
+            #data['vsh'] = 0
+            data['vsh'] = np.where(data['reading'] < 0, 0, data['reading'])
+            data['vsh'] = np.where(data['reading'] > 1, 1, data['reading'])
 
-                IGR = (data[GR].iloc[i] - min_GR) / (max_GR - min_GR)
-                reading = 0.083 * ((2** (3.7 * IGR)) - 1)
-                #reading = (((3.7 * (data[GR].iloc[i] - 25)/(130-25)) ** 2) - 1) * 0.083
-                
-                #To correct for negative volumes of shale as this is practically not correct
 
-                if reading < 0:
-                    vsh.append(0)
+            df3['vsh'] = data['vsh']
 
-                elif reading > 1:
-                    vsh.append(1)
-                else:
-                    vsh.append(reading)
-
-            df3['vsh'] = vsh
-
-            ntg = []
-            for vsh_ in df3['vsh']:
-                amount = 1 - vsh_
-                ntg.append(amount)
-
-            df3['ntg'] = ntg
+            #df3['ntg'] = 0
+            df3['ntg'] = 1 - df3['vsh']
                     
             #Calculating Net Pay using GR and Porosity readings
             
-            net = []
-
-            for i in range(data.shape[0]):
-                if (data[GR].iloc[i] < cutoff_test) and (data[NPHI].iloc[i] > 0.25):
-                    i = 1
-                    net.append(i)
-                else:
-                    i = 0
-                    net.append(i)
-                    
+            df3['Net_Pay'] = np.nan
+            df3.loc[df3[GR] > cutoff_test, 'Net_Pay'] = 0
+            df3.loc[(df3[GR] < cutoff_test) & (df3[NPHI] > 0.25), 'Net_Pay'] = 1
             
-            df3['Net_Pay'] = net
-
-            #df3['litho'] = 0.5 * df3['litho']
-            #df3['Net_Pay'] = 0.5 * df3['Net_Pay']
             
-            #Calculating total formation porosity (phid)
-            
-            FL = 1
+            FL = 1   #Formation liquid (assummed to be water, 0.8 for oil)
 
-            df3['phid'] = 0
-            for i in range(df3.shape[0]):
-                df3['phid'].iloc[i] = (2.65 - df3[RHOB].iloc[i]) / (2.65 - FL)
+            #df3['phid'] = 0
+            df3['phid'] = (2.65 - df3[RHOB]) / (2.65 - FL)
                 
             #Setting cutoff conditions for the porosity values
 
@@ -212,39 +173,20 @@ class FormationEvaluation:
                     
             #Calculating water saturation
             
-            sw = []
+            df3['sw'] = np.nan
+            df3['sw'] = (np.sqrt(0.1/(df3[RT].mean() * (df3['phidf'] ** 1.74))))
+            df3['sw'] = np.where(df3['sw'] < 0, 0, df3['sw'])
+            df3['sw'] = np.where(df3['sw'] > 1, 1, df3['sw'])
             
-            for i in range(df3.shape[0]):
-                #i = np.sqrt(0.10 / (df3[RT].iloc[i]) * (phidf[i] ** 1.74))
-                #if i == float('inf'):
-                j = np.sqrt(0.10/(df3[RT].mean() * (df3['phidf'].iloc[i] ** 1.74)))
-                if j < 0:
-                    sw.append(j)
-                elif j > 1:
-                    sw.append(1)
-                else:
-                    sw.append(j)
+            #j = np.sqrt(0.10/(df3[RT].mean() * (df3['phidf'].iloc[i] ** 1.74)))
                     
             #Calculating oil saturation
             
-            oil_sat = []
-            
-            for i in range(0, df3.shape[0]):
-                i = 1 - sw[i]
-                oil_sat.append(i)
-            
-            df3['vsh'] = vsh
-
-            
-            df3['sw'] = sw
-            df3['oil_sat'] = oil_sat
+            df3['oil_sat'] = 1-df3['sw']
 
             #effective porosity calculation
-            df3['phie'] = 0
-            for i in range(df3.shape[0]):
-                df3['phie'].iloc[i] = df3['phidf'].iloc[i] * df3['ntg'].iloc[i]
-                df3['phie'] = np.where(df3['phie'] < 0, 0, df3['phie'])
-                
+            df3['phie'] = df3['phidf'] * df3['ntg']
+            df3['phie'] = np.where(df3['phie'] < 0, 0, df3['phie'])
             
             #return evaluated parameters
             
